@@ -1,12 +1,15 @@
 """
-# OpenApiLibCore for Robot Framework®
+# OpenApiLibCore for Robot Framework
 
 The OpenApiLibCore library is a utility library that is meant to simplify creation
 of other Robot Framework libraries for API testing based on the information in
 an OpenAPI document (also known as Swagger document).
 This document explains how to use the OpenApiLibCore library.
 
-For more information about Robot Framework®, see http://robotframework.org.
+My RoboCon 2022 talk about OpenApiDriver and OpenApiLibCore can be found
+[here](https://www.youtube.com/watch?v=7YWZEHxk9Ps)
+
+For more information about Robot Framework, see http://robotframework.org.
 
 ---
 
@@ -111,6 +114,7 @@ There are currently a number of limitations to supported API structures, support
 data types and properties. The following list details the most important ones:
 - Only JSON request and response bodies are supported.
 - No support for per-endpoint authorization levels.
+- Parsing of OAS 3.1 documents is supported by the parsing tools, but runtime behavior is untested.
 
 """
 
@@ -797,7 +801,9 @@ class OpenApiLibCore:  # pylint: disable=too-many-instance-attributes
         for key, value in dto_data.items():
             required_properties = content_schema.get("required", [])
             if key in required_properties:
-                fields.append((key, type(value)))
+                # The fields list is used to create a dataclass, so non-default fields
+                # must go before fields with a default
+                fields.insert(0, ((key, type(value))))
             else:
                 fields.append((key, type(value), field(default=None)))  # type: ignore[arg-type]
         return fields
@@ -817,12 +823,14 @@ class OpenApiLibCore:  # pylint: disable=too-many-instance-attributes
     @staticmethod
     def get_content_schema(body_spec: Dict[str, Any]) -> Dict[str, Any]:
         """Get the content schema from the requestBody spec."""
-        # Content should be a single key/value entry, so use tuple assignment
-        (content_type,) = body_spec["content"].keys()
-        if content_type != "application/json":
+        content_types = body_spec["content"].keys()
+        if "application/json" not in content_types:
             # At present no supported for other types.
-            raise NotImplementedError(f"content_type '{content_type}' not supported")
-        content_schema = body_spec["content"][content_type]["schema"]
+            raise NotImplementedError(
+                f"Only content type 'application/json' is supported. "
+                f"Content types definded in the spec are '{content_types}'."
+            )
+        content_schema = body_spec["content"]["application/json"]["schema"]
         resolved_schema: Dict[str, Any] = resolve_schema(content_schema)
         return resolved_schema
 
